#!/usr/bin/python3
#-----------------------------------------------------------------------------
# Project    : Tutoriels - Conception de circuits intégrés analogiques
#-----------------------------------------------------------------------------
# File       : sync.py
# Authors    : Mickael Fiorentino <mickael.fiorentino@polymtl.ca>
# Lab        : GRM - Polytechnique Montréal
# Date       : <2019-07-24 Wed>
#-----------------------------------------------------------------------------
# Description: Synchronisation de la documentation sur le Wiki du GRM
#              - Interface à partir de l'API XML-RPC de DokuWiki
#              - module dokuwiki: https://python-dokuwiki.readthedocs.io
# Usage      : Sur les machines du GRM:
#              % stpython37
#              % pip3 install dokuwiki --user
#              % python3 sync.py 'username' 'passwd'
#-----------------------------------------------------------------------------
import dokuwiki
import argparse
import os

# Arguments
parser = argparse.ArgumentParser()
parser.add_argument("login", type=str, help="Nom d'utilisateur sur le Wiki du GRM")
parser.add_argument("passwd", type=str, help="Mot de passe sur le Wiki du GRM")
args = parser.parse_args()

# Parameters
username  = args.login
password  = args.passwd
namespace = ':tutoriels:analogique:'
wiki_url  = 'https://intranet.grm.polymtl.ca/wiki'
img_dir   = 'img'
page_dir  = 'pages'

# Login
try:
    wiki = dokuwiki.DokuWiki(wiki_url, username, password, cookieAuth=True)
except (DokuWikiError, Exception) as err:
    print('unable to connect: %s' % err)

# Cleaning up directories before backup
for d in [img_dir, page_dir]:
    if not os.path.exists(d):
        os.mkdir(d)

# Backup pages
for p in wiki.pages.list(namespace):
    page = wiki.pages.get(p['id'])
    name = page_dir + '/' + p['id'].split(':')[-1] + '.dwiki'
    with open(name, 'w') as f:
        f.write(page)

# Backup Media
for m in  wiki.medias.list(namespace):
    name = m['id'].split(':')[-1]
    wiki.medias.get(m['id'], dirpath=img_dir, filename=name, overwrite=True)
