#!/usr/bin/env tcsh
#-----------------------------------------------------------------------------
# Project    : Tutoriels - Conception de circuits intégrés analogiques
#-----------------------------------------------------------------------------
# File       : setup.csh
# Authors    : Mickael Fiorentino <mickael.fiorentino@polymtl.ca>
#            : Erika Miller-Jolicoeur <erika.miller-jolicoeur@polymtl.ca>
# Lab        : GRM - Polytechnique Montréal
# Date       : <2019-07-24 Wed>
#-----------------------------------------------------------------------------
# Description: Script de configuration de l'environnement
#              + Environnement CMC
#              + Hiérarchie du projet
#              + kit GPDK045
#              + Outils Cadence 
#-----------------------------------------------------------------------------

#-----------------------------------------------------------------------------
# CONFIGURATION                                                         
#-----------------------------------------------------------------------------

setenv CMC_CONFIG   "/CMC/scripts/cmc.2017.12.csh"
setenv PROJECT_HOME `pwd` 

# setup.csh doit être lancé depuis la racine du projet
if ( ! -f ${PROJECT_HOME}/setup.csh ) then
    echo "ERROR: setup.csh doit être lancé depuis la racine du projet"
    exit 1
endif

# Vérification de l'environnment CMC
if ( ! -f ${CMC_CONFIG} ) then
    echo "ERROR: L'environnement n'est pas configuré pour les outils de CMC"
    exit 1
endif

source ${CMC_CONFIG}

#-----------------------------------------------------------------------------
# OUTILS & KIT GPDK045
#-----------------------------------------------------------------------------

# Kit
setenv KIT_HOME ${CMC_HOME}/kits/GPDK45

# CADENCE
source ${CMC_HOME}/scripts/cadence.2014.12.csh
setenv CDS_LOAD_ENV         addCWD   # .cdsenv
setenv CDS_AUTO_64BIT       ALL
setenv CDS_USE_PALETTE      true
setenv DD_DONT_DO_OS_LOCKS  set
setenv DD_USE_LIBDEFS       no
setenv DRCTEMPDIR /export/tmp/$user

# VIRTUOSO
source ${CMC_HOME}/scripts/cadence.ic617.csh
alias virtuoso "virtuoso -log virtuoso.log"
